@@ -1,10 +1,4 @@
-from starception.exception_handler import (
-    add_link_template,
-    exception_handler,
-    install_error_handler,
-    set_editor,
-    set_theme,
-)
+from starception.exception_handler import add_link_template, exception_handler, install_error_handler, set_editor
 from starception.middleware import StarceptionMiddleware
 
 __all__ = [
@@ -13,5 +7,4 @@ __all__ = [
     'set_editor',
     'add_link_template',
     'install_error_handler',
-    'set_theme',
 ]
