@@ -1,10 +1,10 @@
 import dataclasses
-import typing_extensions
 
 import hashlib
 import html
 import inspect
 import jinja2
+import markupsafe
 import os
 import sys
 import traceback
@@ -15,9 +15,9 @@ from starlette.datastructures import URL
 from starlette.middleware.errors import ServerErrorMiddleware
 from starlette.requests import Request
 from starlette.responses import HTMLResponse, PlainTextResponse, Response
+from urllib.parse import quote_plus
 
 _editor: str = 'none'
-_theme: typing_extensions.Literal['light', 'dark'] = 'light'
 open_link_templates: typing.Dict[str, str] = {
     'none': 'file://{path}',
     'vscode': 'vscode://file/{path}:{lineno}',
@@ -34,11 +34,6 @@ def set_editor(name: str) -> None:
     _editor = name
 
 
-def set_theme(theme: typing_extensions.Literal['light', 'dark']) -> None:
-    global _theme
-    _theme = theme
-
-
 def add_link_template(editor: str, template: str) -> None:
     """
     Add open file link template. The template accepts two format keys: path and
@@ -56,17 +51,13 @@ def to_ide_link(path: str, lineno: int) -> str:
     return template.format(path=path, lineno=lineno)
 
 
-def install_error_handler(
-    theme: typing_extensions.Literal['light', 'dark'] = 'light',
-    editor: str = '',
-) -> None:
+def install_error_handler(editor: str = '') -> None:
     """
     Replace Starlette debug exception handler in-place.
 
     May be, someday, we won't need it.
     See https://github.com/encode/starlette/discussions/1867
     """
-    set_theme(theme)
     set_editor(editor)
 
     def bound_handler(self: ServerErrorMiddleware, request: Request, exc: Exception) -> Response:
@@ -175,7 +166,6 @@ def highlight(value: str, filename: str) -> str:
         from pygments.formatters import HtmlFormatter
         from pygments.lexers import CssLexer, HtmlLexer, JavascriptLexer, PythonLexer
 
-        style = 'xcode' if _theme == 'light' else 'nord'
         *_, extension = os.path.splitext(filename)
         mapping = {
             '.py': PythonLexer(),
@@ -186,10 +176,10 @@ def highlight(value: str, filename: str) -> str:
         }
         lexer = mapping.get(extension)
         if lexer:
-            return highlight(value, lexer, HtmlFormatter(noclasses=True, nowrap=True, style=style))  # type: ignore
+            return highlight(value, lexer, HtmlFormatter(nowrap=True))  # type: ignore
         return value
     except ImportError:
-        return value
+        return markupsafe.escape(value)
 
 
 jinja = jinja2.Environment(loader=jinja2.PackageLoader(__name__))
@@ -228,26 +218,31 @@ def generate_plain_text(exc: Exception) -> str:
 class StackItem:
     exc: Exception
     frames: typing.List[inspect.FrameInfo]
+    has_vendor_frames: bool
     solution: str
 
 
 def generate_html(request: Request, exc: Exception, limit: int = 15) -> str:
     traceback_obj = traceback.TracebackException.from_exception(exc, capture_locals=True)
+    frames = inspect.getinnerframes(exc.__traceback__, limit) if exc.__traceback__ else []
     stack = [
         StackItem(
             exc=exc,
             solution=getattr(exc, 'solution', ''),
-            frames=inspect.getinnerframes(exc.__traceback__, limit) if exc.__traceback__ else [],
+            frames=frames,
+            has_vendor_frames=any(is_vendor(f) for f in frames),
         )
     ]
     exception = exc
     cause = getattr(exception, '__cause__')
     while cause:
+        frames = inspect.getinnerframes(cause.__traceback__, limit) if cause.__traceback__ else []
         stack.append(
             StackItem(
                 exc=cause,
                 solution=getattr(cause, 'solution', ''),
-                frames=inspect.getinnerframes(cause.__traceback__, limit) if cause.__traceback__ else [],
+                frames=frames,
+                has_vendor_frames=any(is_vendor(f) for f in frames),
             )
         )
         cause = getattr(cause, '__cause__')
@@ -255,7 +250,7 @@ def generate_html(request: Request, exc: Exception, limit: int = 15) -> str:
     template = jinja.get_template('index.html')
     return template.render(
         {
-            'theme': _theme,
+            'search_query': quote_plus(f'{format_qual_name(traceback_obj.exc_type)} {str(exc)}'),
             'exception_class': format_qual_name(traceback_obj.exc_type),
             'error_message': str(exc) or '""',
             'stack': stack,
